<?php
/**
 * Discount Feed WooCommerce
 *
 * @package    DiscountFeedWooCommerce
 * @subpackage DiscountFeedWooCommerce Management screen
/*
	Copyright (c) 2018- Katsushi Kawamori (email : dodesyoswift312@gmail.com)
	This program is free software; you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation; version 2 of the License.

	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with this program; if not, write to the Free Software
	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

$discountfeedwoocommerceadmin = new DiscountFeedWooCommerceAdmin();

/** ==================================================
 * Management screen
 */
class DiscountFeedWooCommerceAdmin {

	/** ==================================================
	 * Construct
	 *
	 * @since 1.00
	 */
	public function __construct() {

		add_action( 'admin_menu', array( $this, 'plugin_menu' ) );
		add_action( 'admin_enqueue_scripts', array( $this, 'load_custom_wp_admin_style' ) );
		add_filter( 'plugin_action_links', array( $this, 'settings_link' ), 10, 2 );
		add_filter( 'cron_schedules', array( $this, 'discountfeedwoocommerce_add_intervals' ) );

		if ( ! class_exists( 'DiscountFeedWooCommerce' ) ) {
			require_once( dirname( __FILE__ ) . '/class-discountfeedwoocommerce.php' );
		}
	}

	/** ==================================================
	 * Add a "Settings" link to the plugins page
	 *
	 * @param  array  $links  links array.
	 * @param  string $file   file.
	 * @return array  $links  links array.
	 * @since 1.00
	 */
	public function settings_link( $links, $file ) {
		static $this_plugin;
		if ( empty( $this_plugin ) ) {
			$this_plugin = 'discount-feed-woocommerce/discountfeedwoocommerce.php';
		}
		if ( $file == $this_plugin ) {
			$links[] = '<a href="' . admin_url( 'options-general.php?page=DiscountFeedWooCommerce' ) . '">' . __( 'Settings' ) . '</a>';
		}
			return $links;
	}

	/** ==================================================
	 * Settings page
	 *
	 * @since 1.00
	 */
	public function plugin_menu() {
		add_options_page( 'Discount Feed WooCommerce Options', 'Discount Feed WooCommerce', 'manage_options', 'DiscountFeedWooCommerce', array( $this, 'plugin_options' ) );
	}

	/** ==================================================
	 * Add Css and Script
	 *
	 * @since 1.00
	 */
	public function load_custom_wp_admin_style() {
		if ( $this->is_my_plugin_screen() ) {
			wp_enqueue_style( 'jquery-responsiveTabs', plugin_dir_url( __DIR__ ) . 'css/responsive-tabs.css', array(), '1.4.0' );
			wp_enqueue_style( 'jquery-responsiveTabs-style', plugin_dir_url( __DIR__ ) . 'css/style.css', array(), '1.4.0' );
			wp_enqueue_script( 'jquery' );
			wp_enqueue_script( 'jquery-responsiveTabs', plugin_dir_url( __DIR__ ) . 'js/jquery.responsiveTabs.min.js', array(), '1.4.0', false );
			wp_enqueue_script( 'discountfeedwoocommerce-js', plugin_dir_url( __DIR__ ) . 'js/jquery.discountfeedwoocommerce.js', array( 'jquery' ), '1.00', false );
		}
	}

	/** ==================================================
	 * For only admin style
	 *
	 * @since 1.00
	 */
	private function is_my_plugin_screen() {
		$screen = get_current_screen();
		if ( is_object( $screen ) && 'settings_page_DiscountFeedWooCommerce' == $screen->id ) {
			return true;
		} else {
			return false;
		}
	}

	/** ==================================================
	 * Settings page
	 *
	 * @since 1.00
	 */
	public function plugin_options() {

		if ( ! current_user_can( 'manage_options' ) ) {
			wp_die( esc_html__( 'You do not have sufficient permissions to access this page.' ) );
		}

		$this->options_updated();

		$scriptname = admin_url( 'options-general.php?page=DiscountFeedWooCommerce' );

		$discountfeedwoocommerce_option = get_option( 'discount_feed_woocommerce' );

		?>

	<div class="wrap">
	<h2>Discount Feed WooCommerce</h2>

	<div id="discountfeedwoocommerce-admin-tabs">
	  <ul>
		<li><a href="#discountfeedwoocommerce-admin-tabs-1"><?php esc_html_e( 'Settings' ); ?></a></li>
		<li><a href="#discountfeedwoocommerce-admin-tabs-2"><?php esc_html_e( 'Donate to this plugin &#187;' ); ?></a></li>
	  </ul>

	  <div id="discountfeedwoocommerce-admin-tabs-1">
		<div class="wrap">

			<h2><?php esc_html_e( 'Settings' ); ?></h2>	

			<form method="post" action="<?php echo esc_url( $scriptname ); ?>">
			<?php wp_nonce_field( 'discountfeedwoocommerce_settings', 'discountfeedwoocommerce_tabs' ); ?>

			<?php submit_button( __( 'Update' ), 'primary', 'Submit', false ); ?>
			<?php submit_button( __( 'Default' ), 'large', 'Default', false ); ?>
			<div style="width: 100%; height: 100%; margin: 5px; padding: 5px; border: #CCC 2px solid;">
				<div style="display: block; padding:5px 5px;">
					<h3><?php esc_html_e( 'Sale', 'discount-feed-woocommerce' ); ?> <?php esc_html_e( 'Tags' ); ?></h3>
					<div style="display: block; padding:5px 15px;">
						<div style="display: block; padding:5px 25px;">
							<li>
							[<b>%regular_price%</b> : <?php esc_html_e( 'List price', 'discount-feed-woocommerce' ); ?>]
							[<b>%sale_price%</b> : <?php esc_html_e( 'Sale price', 'discount-feed-woocommerce' ); ?>]
							[<b>%dis_amount%</b> : <?php esc_html_e( 'Discount amount', 'discount-feed-woocommerce' ); ?>]
							[<b>%dis_rate%</b> : <?php esc_html_e( 'Discount rate', 'discount-feed-woocommerce' ); ?>]
							[<b>%to_date%</b> : <?php esc_html_e( 'Last day of sale', 'discount-feed-woocommerce' ); ?>]
							[<b>%interval_day%</b> : <?php esc_html_e( 'Remaining number of selling days', 'discount-feed-woocommerce' ); ?>]
							[<b>%interval_time%</b> : <?php esc_html_e( 'Remaining sales time', 'discount-feed-woocommerce' ); ?>]
							</li>
							<li><b><?php esc_html_e( 'Please write any letters between tags. You can move and delete tags freely.', 'discount-feed-woocommerce' ); ?></b></li>
							<div>
							<textarea name="discountfeedwoocommerce_woo_sale_text" style="width: 100%;"><?php echo esc_textarea( $discountfeedwoocommerce_option['sale_text_tag'] ); ?></textarea>
							</div>
						</div>
					</div>
					<h3><?php esc_html_e( 'Coupon', 'discount-feed-woocommerce' ); ?> <?php esc_html_e( 'Tags' ); ?></h3>
					<div style="display: block; padding:5px 15px;">
						<div style="display: block; padding:5px 25px;">
							<li>
							[<b>%coupon_code%</b> : <?php esc_html_e( 'Coupon Code', 'discount-feed-woocommerce' ); ?>]
							[<b>%discount%</b> : <?php esc_html_e( 'Discount', 'discount-feed-woocommerce' ); ?>]
							[<b>%expiry_date%</b> : <?php esc_html_e( 'Last day of coupon', 'discount-feed-woocommerce' ); ?>]
							[<b>%product%</b> : <?php esc_html_e( 'Apply Product', 'discount-feed-woocommerce' ); ?>]
							[<b>%exclude_product%</b> : <?php esc_html_e( 'Exclude Product', 'discount-feed-woocommerce' ); ?>]
							[<b>%product_categories%</b> : <?php esc_html_e( 'Apply Category', 'discount-feed-woocommerce' ); ?>]
							[<b>%exclude_product_categories%</b> : <?php esc_html_e( 'Exclude Category', 'discount-feed-woocommerce' ); ?>]
							</li>
							<li><b><?php esc_html_e( 'Please write any letters between tags. You can move and delete tags freely.', 'discount-feed-woocommerce' ); ?></b></li>
							<div>
							<textarea name="discountfeedwoocommerce_woo_coupon_text" style="width: 100%;"><?php echo esc_textarea( $discountfeedwoocommerce_option['coupon_text_tag'] ); ?></textarea>
							</div>
						</div>
					</div>
				</div>
			</div>

			<div style="width: 100%; height: 100%; margin: 5px; padding: 5px; border: #CCC 2px solid;">
				<div style="display: block; padding:5px 15px;">
					<h3><?php esc_html_e( 'Schedule', 'discount-feed-woocommerce' ); ?></h3>
					<div style="display:block;padding:5px 15px">
					<?php esc_html_e( 'Set the schedule.', 'discount-feed-woocommerce' ); ?>
					<?php esc_html_e( 'Will take some time until the [Next Schedule] is reflected.', 'discount-feed-woocommerce' ); ?>
					</div>
					<?php
					if ( wp_next_scheduled( 'DiscountFeedWooCommerceHook' ) ) {
						$next_schedule = ' ' . get_date_from_gmt( date( 'Y-m-d H:i:s', wp_next_scheduled( 'DiscountFeedWooCommerceHook' ) ) );
					} else {
						$next_schedule = ' ' . __( 'None' );
					}
					?>
					<div style="display:block;padding:5px 15px">
					<?php echo esc_html( __( 'Next Schedule:', 'discount-feed-woocommerce' ) . $next_schedule ); ?>
					</div>
					<div style="display:block;padding:5px 25px">
					<input type="radio" name="discountfeedwoocommerce_schedule" value="daily" <?php checked( 'daily', $discountfeedwoocommerce_option['schedule'] ); ?>>
					<?php esc_html_e( 'daily', 'discount-feed-woocommerce' ); ?>
					</div>
					<div style="display:block;padding:5px 25px">
					<input type="radio" name="discountfeedwoocommerce_schedule" value="weekly" <?php checked( 'weekly', $discountfeedwoocommerce_option['schedule'] ); ?>>
					<?php esc_html_e( 'weekly', 'discount-feed-woocommerce' ); ?>
					</div>
					<div style="display:block;padding:5px 25px">
					<input type="radio" name="discountfeedwoocommerce_schedule" value="2weeks" <?php checked( '2weeks', $discountfeedwoocommerce_option['schedule'] ); ?>>
					<?php esc_html_e( '2weeks', 'discount-feed-woocommerce' ); ?>
					</div>
					<div style="display:block;padding:5px 25px">
					<input type="radio" name="discountfeedwoocommerce_schedule" value="3weeks" <?php checked( '3weeks', $discountfeedwoocommerce_option['schedule'] ); ?>>
					<?php esc_html_e( '3weeks', 'discount-feed-woocommerce' ); ?>
					</div>
					<div style="display:block;padding:5px 25px">
					<input type="radio" name="discountfeedwoocommerce_schedule" value="monthly" <?php checked( 'monthly', $discountfeedwoocommerce_option['schedule'] ); ?>>
					<?php esc_html_e( 'monthly', 'discount-feed-woocommerce' ); ?>
					</div>
				</div>
			</div>

			<div style="width: 100%; height: 100%; margin: 5px; padding: 5px; border: #CCC 2px solid;">
				<div style="display: block; padding:5px 15px;">
					<h3><?php esc_html_e( 'Feed', 'discount-feed-woocommerce' ); ?></h3>
					<div style="display:block;padding:5px 15px">
					<?php esc_html_e( 'A feed is created at the following URL. If you get a 404 error, please save permalink settings.', 'discount-feed-woocommerce' ); ?>
					<input name="feed_url" style="width: 75%;" type="text" value="<?php echo esc_url( get_feed_link( 'dcfeedwoo' ) ); ?>" readonly="readonly" />
					</div>
				</div>
				<div style="display: block; padding:5px 15px;">
					<h3><?php esc_html_e( 'Custom Post Type', 'discount-feed-woocommerce' ); ?></h3>
					<div style="display:block;padding:5px 15px">
					<?php esc_html_e( 'When you create a feed, a custom post is created.', 'discount-feed-woocommerce' ); ?>
					<div><a style="text-decoration: none;" href="<?php echo esc_url( admin_url( 'edit.php?post_type=dcfeedwoo_product' ) ); ?>"><?php esc_html_e( 'Custom Post Type', 'discount-feed-woocommerce' ); ?></a></div>
					</div>
				</div>
				<div style="display: block; padding:5px 15px;">
					<h3><?php esc_html_e( 'Widget' ); ?></h3>
					<div style="display:block;padding:5px 15px">
					<?php esc_html_e( 'Can set up feed widgets.', 'discount-feed-woocommerce' ); ?>
					<div><a style="text-decoration: none;" href="<?php echo esc_url( admin_url( 'widgets.php' ) ); ?>"><?php esc_html_e( 'Widget' ); ?></a></div>
					</div>
				</div>
			</div>

			<?php submit_button( __( 'Update' ), 'primary', 'Submit', false ); ?>

			</form>

		</div>
	  </div>

	  <div id="discountfeedwoocommerce-admin-tabs-2">
		<div class="wrap">
		<?php $this->credit(); ?>
		</div>
	  </div>

	</div>
	</div>
		<?php

	}

	/** ==================================================
	 * Credit
	 *
	 * @since 1.00
	 */
	private function credit() {

		$plugin_name    = null;
		$plugin_ver_num = null;
		$plugin_path    = plugin_dir_path( __DIR__ );
		$plugin_dir     = untrailingslashit( $plugin_path );
		$slugs          = explode( '/', $plugin_dir );
		$slug           = end( $slugs );
		$files          = scandir( $plugin_dir );
		foreach ( $files as $file ) {
			if ( '.' === $file || '..' === $file || is_dir( $plugin_path . $file ) ) {
				continue;
			} else {
				$exts = explode( '.', $file );
				$ext  = strtolower( end( $exts ) );
				if ( 'php' === $ext ) {
					$plugin_datas = get_file_data(
						$plugin_path . $file,
						array(
							'name'    => 'Plugin Name',
							'version' => 'Version',
						)
					);
					if ( array_key_exists( 'name', $plugin_datas ) && ! empty( $plugin_datas['name'] ) && array_key_exists( 'version', $plugin_datas ) && ! empty( $plugin_datas['version'] ) ) {
						$plugin_name    = $plugin_datas['name'];
						$plugin_ver_num = $plugin_datas['version'];
						break;
					}
				}
			}
		}
		$plugin_version = __( 'Version:' ) . ' ' . $plugin_ver_num;
		/* translators: FAQ Link & Slug */
		$faq       = sprintf( esc_html__( 'https://wordpress.org/plugins/%s/faq', '%s' ), $slug );
		$support   = 'https://wordpress.org/support/plugin/' . $slug;
		$review    = 'https://wordpress.org/support/view/plugin-reviews/' . $slug;
		$translate = 'https://translate.wordpress.org/projects/wp-plugins/' . $slug;
		$facebook  = 'https://www.facebook.com/katsushikawamori/';
		$twitter   = 'https://twitter.com/dodesyo312';
		$youtube   = 'https://www.youtube.com/channel/UC5zTLeyROkvZm86OgNRcb_w';
		$donate    = sprintf( esc_html__( 'https://shop.riverforest-wp.info/donate/', '%s' ), $slug );

		?>
		<span style="font-weight: bold;">
		<div>
		<?php echo esc_html( $plugin_version ); ?> | 
		<a style="text-decoration: none;" href="<?php echo esc_url( $faq ); ?>" target="_blank"><?php esc_html_e( 'FAQ' ); ?></a> | <a style="text-decoration: none;" href="<?php echo esc_url( $support ); ?>" target="_blank"><?php esc_html_e( 'Support Forums' ); ?></a> | <a style="text-decoration: none;" href="<?php echo esc_url( $review ); ?>" target="_blank"><?php sprintf( esc_html_e( 'Reviews', '%s' ), $slug ); ?></a>
		</div>
		<div>
		<a style="text-decoration: none;" href="<?php echo esc_url( $translate ); ?>" target="_blank">
		<?php
		/* translators: Plugin translation link */
		echo sprintf( esc_html__( 'Translations for %s' ), esc_html( $plugin_name ) );
		?>
		</a> | <a style="text-decoration: none;" href="<?php echo esc_url( $facebook ); ?>" target="_blank"><span class="dashicons dashicons-facebook"></span></a> | <a style="text-decoration: none;" href="<?php echo esc_url( $twitter ); ?>" target="_blank"><span class="dashicons dashicons-twitter"></span></a> | <a style="text-decoration: none;" href="<?php echo esc_url( $youtube ); ?>" target="_blank"><span class="dashicons dashicons-video-alt3"></span></a>
		</div>
		</span>

		<div style="width: 250px; height: 180px; margin: 5px; padding: 5px; border: #CCC 2px solid;">
		<h3><?php sprintf( esc_html_e( 'Please make a donation if you like my work or would like to further the development of this plugin.', '%s' ), $slug ); ?></h3>
		<div style="text-align: right; margin: 5px; padding: 5px;"><span style="padding: 3px; color: #ffffff; background-color: #008000">Plugin Author</span> <span style="font-weight: bold;">Katsushi Kawamori</span></div>
		<button type="button" style="margin: 5px; padding: 5px;" onclick="window.open('<?php echo esc_url( $donate ); ?>')"><?php esc_html_e( 'Donate to this plugin &#187;' ); ?></button>
		</div>

		<?php

	}

	/** ==================================================
	 * Update wp_options table.
	 *
	 * @since 1.00
	 */
	private function options_updated() {

		if ( ! empty( $_POST ) ) {
			if ( isset( $_POST['discountfeedwoocommerce_tabs'] ) && ! empty( $_POST['discountfeedwoocommerce_tabs'] ) ) {
				if ( check_admin_referer( 'discountfeedwoocommerce_settings', 'discountfeedwoocommerce_tabs' ) ) {
					$woo_sale_text_tag = __( 'List price', 'discount-feed-woocommerce' ) . ' %regular_price% >> ' . __( 'Sale price', 'discount-feed-woocommerce' ) . ' %sale_price% !! %dis_amount% !! %dis_rate% !! ' . __( 'Last day of sale', 'discount-feed-woocommerce' ) . ' %to_date%. ' . __( 'Remaining datetime', 'discount-feed-woocommerce' ) . ' %interval_day% %interval_time% !!';
					$woo_coupon_text_tag = '[' . __( 'Coupon Code', 'discount-feed-woocommerce' ) . ' : %coupon_code%] >> [' . __( 'Discount', 'discount-feed-woocommerce' ) . ' : %discount%][' . __( 'Last day of coupon', 'discount-feed-woocommerce' ) . ' : %expiry_date%][' . __( 'Apply Product', 'discount-feed-woocommerce' ) . ' : %product%][' . __( 'Exclude Product', 'discount-feed-woocommerce' ) . ' : %exclude_product%][' . __( 'Apply Category', 'discount-feed-woocommerce' ) . ' : %product_categories%][' . __( 'Exclude Category', 'discount-feed-woocommerce' ) . ' : %exclude_product_categories%]';
					$discount_feed_woocommerce_reset_tbl = array(
						'sale_text_tag' => $woo_sale_text_tag,
						'coupon_text_tag' => $woo_coupon_text_tag,
						'schedule'      => 'daily',
					);

					if ( ! empty( $_POST['Default'] ) ) {
						update_option( 'discount_feed_woocommerce', $discount_feed_woocommerce_reset_tbl );
						echo '<div class="notice notice-success is-dismissible"><ul><li>' . esc_html( __( 'Settings' ) . ' --> ' . __( 'Default' ) . ' --> ' . __( 'Changes saved.' ) ) . '</li></ul></div>';
					} else {
						$discount_feed_woocommerce_settings = get_option( 'discount_feed_woocommerce' );
						if ( ! empty( $_POST['discountfeedwoocommerce_woo_sale_text'] ) ) {
							$discount_feed_woocommerce_settings['sale_text_tag'] = wp_strip_all_tags( wp_unslash( $_POST['discountfeedwoocommerce_woo_sale_text'] ) );
						}
						if ( ! empty( $_POST['discountfeedwoocommerce_woo_coupon_text'] ) ) {
							$discount_feed_woocommerce_settings['coupon_text_tag'] = wp_strip_all_tags( wp_unslash( $_POST['discountfeedwoocommerce_woo_coupon_text'] ) );
						}
						if ( ! empty( $_POST['discountfeedwoocommerce_schedule'] ) ) {
							$discount_feed_woocommerce_settings['schedule'] = sanitize_text_field( wp_unslash( $_POST['discountfeedwoocommerce_schedule'] ) );
						}
						update_option( 'discount_feed_woocommerce', $discount_feed_woocommerce_settings );
						echo '<div class="notice notice-success is-dismissible"><ul><li>' . esc_html( __( 'Settings' ) . ' --> ' . __( 'Changes saved.' ) ) . '</li></ul></div>';
					}
					$discountfeedwoocommerce = new DiscountFeedWooCommerce();
					$result = $discountfeedwoocommerce->cron_start();
					if ( false === $result ) {
						echo '<div class="notice notice-error is-dismissible"><ul><li>' . esc_html__( 'The feed was not created. Perhaps WordPress scheduling system is busy. Please "Update" again.', 'discount-feed-woocommerce' ) . '</li></ul></div>';
					} else {
						echo '<div class="notice notice-success is-dismissible"><ul><li>' . esc_html__( 'The feed was created and the schedule started.', 'discount-feed-woocommerce' ) . '</li></ul></div>';
					}
				}
			}
		}

	}

	/** ==================================================
	 * Intervals
	 *
	 * @param array $schedules  schedules.
	 * @return array $schedules
	 * @since 1.00
	 */
	public function discountfeedwoocommerce_add_intervals( $schedules ) {

		$schedules['weekly'] = array(
			'interval' => 604800,
			'display' => __( 'weekly', 'discount-feed-woocommerce' ),
		);
		$schedules['2weeks'] = array(
			'interval' => 1209600,
			'display' => __( '2weeks', 'discount-feed-woocommerce' ),
		);
		$schedules['3weeks'] = array(
			'interval' => 1814400,
			'display' => __( '3weeks', 'discount-feed-woocommerce' ),
		);
		$schedules['monthly'] = array(
			'interval' => 2635200,
			'display' => __( 'monthly', 'discount-feed-woocommerce' ),
		);

		return $schedules;

	}

}


