<?php
/**
 * Discount Feed WooCommerce
 *
 * @package    DiscountFeedWooCommerce
 * @subpackage DiscountFeedWooCommerce registered in the database
/*
	Copyright (c) 2018- Katsushi Kawamori (email : dodesyoswift312@gmail.com)
	This program is free software; you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation; version 2 of the License.

	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with this program; if not, write to the Free Software
	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

$discountfeedwoocommerceregist = new DiscountFeedWooCommerceRegist();

/** ==================================================
 * Registered in the database
 */
class DiscountFeedWooCommerceRegist {

	/** ==================================================
	 * Construct
	 *
	 * @since 1.00
	 */
	public function __construct() {

		add_action( 'admin_init', array( $this, 'register_settings' ) );
		add_action( 'init', array( $this, 'create_post_type' ) );

	}

	/** ==================================================
	 * Settings register
	 *
	 * @since 1.00
	 */
	public function register_settings() {

		$woo_sale_text_tag = __( 'List price', 'discount-feed-woocommerce' ) . ' %regular_price% >> ' . __( 'Sale price', 'discount-feed-woocommerce' ) . ' %sale_price% !! %dis_amount% !! %dis_rate% !! ' . __( 'Last day of sale', 'discount-feed-woocommerce' ) . ' %to_date%. ' . __( 'Remaining datetime', 'discount-feed-woocommerce' ) . ' %interval_day% %interval_time% !!';
		$woo_coupon_text_tag = '[' . __( 'Coupon Code', 'discount-feed-woocommerce' ) . ' : %coupon_code%] >> [' . __( 'Discount', 'discount-feed-woocommerce' ) . ' : %discount%][' . __( 'Last day of coupon', 'discount-feed-woocommerce' ) . ' : %expiry_date%][' . __( 'Apply Product', 'discount-feed-woocommerce' ) . ' : %product%][' . __( 'Exclude Product', 'discount-feed-woocommerce' ) . ' : %exclude_product%][' . __( 'Apply Category', 'discount-feed-woocommerce' ) . ' : %product_categories%][' . __( 'Exclude Category', 'discount-feed-woocommerce' ) . ' : %exclude_product_categories%]';

		$discount_feed_woocommerce_tbl = array(
			'sale_text_tag' => $woo_sale_text_tag,
			'coupon_text_tag' => $woo_coupon_text_tag,
			'schedule'      => 'daily',
		);

		if ( ! get_option( 'discount_feed_woocommerce' ) ) {
			update_option( 'discount_feed_woocommerce', $discount_feed_woocommerce_tbl );
		}

		$discount_feed_woocommerce_link = get_feed_link( 'dcfeedwoo' );
		$discount_feed_woocommerce_widget = array(
			'dcfeedwoo' => $discount_feed_woocommerce_link,
		);
		update_option( 'discount_feed_woocommerce_widget', $discount_feed_woocommerce_widget );

	}

	/** ==================================================
	 * Custom post type
	 *
	 * @since 1.00
	 */
	public function create_post_type() {

		register_post_type(
			'dcfeedwoo_product',
			array(
				'labels' => array(
					'name' => __( 'Discount Feeds', 'discount-feed-woocommerce' ),
					'singular_name' => __( 'Discount Feed', 'discount-feed-woocommerce' ),
				),
				'public' => true,
				'show_in_rest' => true,
				'has_archive' => true,
				'supports' => array(
					'title',
					'editor',
					'thumbnail',
					'revisions',
					'author',
				),
				'rewrite' => array( 'slug' => 'dcfeedwoo' ),
			)
		);

	}

}


